'use strict';

var chalk = require('chalk');
var fs = require('fs');
var npm = require('npm');
var Package = require('./package');

var die = function die(message) {
    return console.error(chalk.bold.red(message));
};
var warn = function warn(message) {
    return console.warn(chalk.yellow(message));
};

fs.readFile('package.json', 'utf-8', function (error, contents) {

    if (contents === undefined) {
        return die('There doesn\'t seem to be a package.json here');
    }

    var packageContents = new Package(contents);

    if (!packageContents.isValid()) {
        return die('Invalid package.json contents');
    }

    if (!packageContents.hasPeerDependencies()) {
        return warn('This package doesn\'t seem to have any peerDependencies');
    }

    var peerDependencies = packageContents.peerDependencies;

    var packages = Object.keys(peerDependencies).map(function (key) {
        return key + '@' + peerDependencies[key];
    });

    var peerInstallOptions = packageContents.peerInstallOptions;

    peerInstallOptions['save'] = false;
    npm.load(peerInstallOptions, function () {
        npm.commands.install(packages);
    });
});